==> redshift-0.10.0-sources.jar: software/amazon/awscdk/services/redshift/cloudformation/ClusterSubnetGroupResourceProps.java <==
package software.amazon.awscdk.services.redshift.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-27T21:43:53.424Z")
public interface ClusterSubnetGroupResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-description
     */
    java.lang.Object getDescription();
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-description
     */
    void setDescription(final java.lang.String value);
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-description
     */
    void setDescription(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-subnetids
     */
    java.lang.Object getSubnetIds();
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-subnetids
     */
    void setSubnetIds(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-subnetids
     */
    void setSubnetIds(final java.util.List<java.lang.Object> value);
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-tags
     */
    java.lang.Object getTags();
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-tags
     */
    void setTags(final software.amazon.awscdk.CloudFormationToken value);
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-tags
     */
    void setTags(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link ClusterSubnetGroupResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link ClusterSubnetGroupResourceProps}
     */
    final class Builder {
        private java.lang.Object _description;
        private java.lang.Object _subnetIds;
        @javax.annotation.Nullable
        private java.lang.Object _tags;

        /**
         * Sets the value of Description
         * @param value ``AWS::Redshift::ClusterSubnetGroup.Description``
         * @return {@code this}
         */
        public Builder withDescription(final java.lang.String value) {
            this._description = java.util.Objects.requireNonNull(value, "description is required");
            return this;
        }
        /**
         * Sets the value of Description
         * @param value ``AWS::Redshift::ClusterSubnetGroup.Description``
         * @return {@code this}
         */
        public Builder withDescription(final software.amazon.awscdk.CloudFormationToken value) {
            this._description = java.util.Objects.requireNonNull(value, "description is required");
            return this;
        }
        /**
         * Sets the value of SubnetIds
         * @param value ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
         * @return {@code this}
         */
        public Builder withSubnetIds(final software.amazon.awscdk.CloudFormationToken value) {
            this._subnetIds = java.util.Objects.requireNonNull(value, "subnetIds is required");
            return this;
        }
        /**
         * Sets the value of SubnetIds
         * @param value ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
         * @return {@code this}
         */
        public Builder withSubnetIds(final java.util.List<java.lang.Object> value) {
            this._subnetIds = java.util.Objects.requireNonNull(value, "subnetIds is required");
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::Redshift::ClusterSubnetGroup.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this._tags = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::Redshift::ClusterSubnetGroup.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ClusterSubnetGroupResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public ClusterSubnetGroupResourceProps build() {
            return new ClusterSubnetGroupResourceProps() {
                private java.lang.Object $description = java.util.Objects.requireNonNull(_description, "description is required");
                private java.lang.Object $subnetIds = java.util.Objects.requireNonNull(_subnetIds, "subnetIds is required");
                @javax.annotation.Nullable
                private java.lang.Object $tags = _tags;

                @Override
                public java.lang.Object getDescription() {
                    return this.$description;
                }

                @Override
                public void setDescription(final java.lang.String value) {
                    this.$description = java.util.Objects.requireNonNull(value, "description is required");
                }

                @Override
                public void setDescription(final software.amazon.awscdk.CloudFormationToken value) {
                    this.$description = java.util.Objects.requireNonNull(value, "description is required");
                }

                @Override
                public java.lang.Object getSubnetIds() {
                    return this.$subnetIds;
                }

                @Override
                public void setSubnetIds(final software.amazon.awscdk.CloudFormationToken value) {
                    this.$subnetIds = java.util.Objects.requireNonNull(value, "subnetIds is required");
                }

                @Override
                public void setSubnetIds(final java.util.List<java.lang.Object> value) {
                    this.$subnetIds = java.util.Objects.requireNonNull(value, "subnetIds is required");
                }

                @Override
                public java.lang.Object getTags() {
                    return this.$tags;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
                    this.$tags = value;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$tags = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.redshift.cloudformation.ClusterSubnetGroupResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-description
         */
        @Override
        public java.lang.Object getDescription() {
            return this.jsiiGet("description", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-description
         */
        @Override
        public void setDescription(final java.lang.String value) {
            this.jsiiSet("description", java.util.Objects.requireNonNull(value, "description is required"));
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-description
         */
        @Override
        public void setDescription(final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("description", java.util.Objects.requireNonNull(value, "description is required"));
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-subnetids
         */
        @Override
        public java.lang.Object getSubnetIds() {
            return this.jsiiGet("subnetIds", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-subnetids
         */
        @Override
        public void setSubnetIds(final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("subnetIds", java.util.Objects.requireNonNull(value, "subnetIds is required"));
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-subnetids
         */
        @Override
        public void setSubnetIds(final java.util.List<java.lang.Object> value) {
            this.jsiiSet("subnetIds", java.util.Objects.requireNonNull(value, "subnetIds is required"));
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-tags
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getTags() {
            return this.jsiiGet("tags", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.CloudFormationToken value) {
            this.jsiiSet("tags", value);
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("tags", value);
        }
    }
}

==> redshift-0.11.0-sources.jar: software/amazon/awscdk/services/redshift/cloudformation/ClusterSubnetGroupResourceProps.java <==
package software.amazon.awscdk.services.redshift.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.7 (build b1c202b)", date = "2018-10-11T17:59:22.550Z")
public interface ClusterSubnetGroupResourceProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-description
     */
    java.lang.Object getDescription();
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-description
     */
    void setDescription(final java.lang.String value);
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.Description``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-description
     */
    void setDescription(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-subnetids
     */
    java.lang.Object getSubnetIds();
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-subnetids
     */
    void setSubnetIds(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-subnetids
     */
    void setSubnetIds(final java.util.List<java.lang.Object> value);
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-tags
     */
    java.lang.Object getTags();
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-tags
     */
    void setTags(final software.amazon.awscdk.Token value);
    /**
     * ``AWS::Redshift::ClusterSubnetGroup.Tags``
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-tags
     */
    void setTags(final java.util.List<java.lang.Object> value);

    /**
     * @return a {@link Builder} of {@link ClusterSubnetGroupResourceProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link ClusterSubnetGroupResourceProps}
     */
    final class Builder {
        private java.lang.Object _description;
        private java.lang.Object _subnetIds;
        @javax.annotation.Nullable
        private java.lang.Object _tags;

        /**
         * Sets the value of Description
         * @param value ``AWS::Redshift::ClusterSubnetGroup.Description``
         * @return {@code this}
         */
        public Builder withDescription(final java.lang.String value) {
            this._description = java.util.Objects.requireNonNull(value, "description is required");
            return this;
        }
        /**
         * Sets the value of Description
         * @param value ``AWS::Redshift::ClusterSubnetGroup.Description``
         * @return {@code this}
         */
        public Builder withDescription(final software.amazon.awscdk.Token value) {
            this._description = java.util.Objects.requireNonNull(value, "description is required");
            return this;
        }
        /**
         * Sets the value of SubnetIds
         * @param value ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
         * @return {@code this}
         */
        public Builder withSubnetIds(final software.amazon.awscdk.Token value) {
            this._subnetIds = java.util.Objects.requireNonNull(value, "subnetIds is required");
            return this;
        }
        /**
         * Sets the value of SubnetIds
         * @param value ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
         * @return {@code this}
         */
        public Builder withSubnetIds(final java.util.List<java.lang.Object> value) {
            this._subnetIds = java.util.Objects.requireNonNull(value, "subnetIds is required");
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::Redshift::ClusterSubnetGroup.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this._tags = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value ``AWS::Redshift::ClusterSubnetGroup.Tags``
         * @return {@code this}
         */
        public Builder withTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ClusterSubnetGroupResourceProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public ClusterSubnetGroupResourceProps build() {
            return new ClusterSubnetGroupResourceProps() {
                private java.lang.Object $description = java.util.Objects.requireNonNull(_description, "description is required");
                private java.lang.Object $subnetIds = java.util.Objects.requireNonNull(_subnetIds, "subnetIds is required");
                @javax.annotation.Nullable
                private java.lang.Object $tags = _tags;

                @Override
                public java.lang.Object getDescription() {
                    return this.$description;
                }

                @Override
                public void setDescription(final java.lang.String value) {
                    this.$description = java.util.Objects.requireNonNull(value, "description is required");
                }

                @Override
                public void setDescription(final software.amazon.awscdk.Token value) {
                    this.$description = java.util.Objects.requireNonNull(value, "description is required");
                }

                @Override
                public java.lang.Object getSubnetIds() {
                    return this.$subnetIds;
                }

                @Override
                public void setSubnetIds(final software.amazon.awscdk.Token value) {
                    this.$subnetIds = java.util.Objects.requireNonNull(value, "subnetIds is required");
                }

                @Override
                public void setSubnetIds(final java.util.List<java.lang.Object> value) {
                    this.$subnetIds = java.util.Objects.requireNonNull(value, "subnetIds is required");
                }

                @Override
                public java.lang.Object getTags() {
                    return this.$tags;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                    this.$tags = value;
                }

                @Override
                public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
                    this.$tags = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.redshift.cloudformation.ClusterSubnetGroupResourceProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-description
         */
        @Override
        public java.lang.Object getDescription() {
            return this.jsiiGet("description", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-description
         */
        @Override
        public void setDescription(final java.lang.String value) {
            this.jsiiSet("description", java.util.Objects.requireNonNull(value, "description is required"));
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.Description``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-description
         */
        @Override
        public void setDescription(final software.amazon.awscdk.Token value) {
            this.jsiiSet("description", java.util.Objects.requireNonNull(value, "description is required"));
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-subnetids
         */
        @Override
        public java.lang.Object getSubnetIds() {
            return this.jsiiGet("subnetIds", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-subnetids
         */
        @Override
        public void setSubnetIds(final software.amazon.awscdk.Token value) {
            this.jsiiSet("subnetIds", java.util.Objects.requireNonNull(value, "subnetIds is required"));
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.SubnetIds``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-subnetids
         */
        @Override
        public void setSubnetIds(final java.util.List<java.lang.Object> value) {
            this.jsiiSet("subnetIds", java.util.Objects.requireNonNull(value, "subnetIds is required"));
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-tags
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getTags() {
            return this.jsiiGet("tags", java.lang.Object.class);
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
            this.jsiiSet("tags", value);
        }

        /**
         * ``AWS::Redshift::ClusterSubnetGroup.Tags``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-clustersubnetgroup.html#cfn-redshift-clustersubnetgroup-tags
         */
        @Override
        public void setTags(@javax.annotation.Nullable final java.util.List<java.lang.Object> value) {
            this.jsiiSet("tags", value);
        }
    }
}
